@@ -1,5 +1,5 @@
 package Net::Twitter::Core;
-$Net::Twitter::Core::VERSION = '4.01020';
+$Net::Twitter::Core::VERSION = '4.01040';
 # ABSTRACT: A perl interface to the Twitter API
 
 use 5.008001;
@@ -271,10 +271,10 @@ sub _parse_result {
 
     return $obj if $res->is_success && defined $obj;
 
-    my $error = Net::Twitter::Error->new(http_response => $res);
-    $error->twitter_error($obj) if ref $obj;
-
-    die $error;
+    die Net::Twitter::Error->new(
+        http_response => $res,
+        $obj ? ( twitter_error => $obj ) : (),
+    );
 }
 
 # Return a DateTime object, given $since as one of:
@@ -358,7 +358,7 @@ Net::Twitter::Core - Net::Twitter implementation
 
 =head1 VERSION
 
-version 4.01020
+version 4.01040
 
 =head1 SYNOPSIS
 
