@@ -1,5 +1,5 @@
 package Net::Twitter::Role::API::RESTv1_1;
-$Net::Twitter::Role::API::RESTv1_1::VERSION = '4.01020';
+$Net::Twitter::Role::API::RESTv1_1::VERSION = '4.01040';
 use Moose::Role;
 use Carp::Clan qw/^(?:Net::Twitter|Moose|Class::MOP)/;
 use Net::Twitter::API;
@@ -132,7 +132,10 @@ authenticating user must be the author of the specified status.
 twitter_api_method update => (
     path       => 'statuses/update',
     method     => 'POST',
-    params     => [qw/media_ids status lat long place_id display_coordinates in_reply_to_status_id trim_user/],
+    params     => [qw/
+        attachment_url display_coordinates in_reply_to_status_id lat long
+        media_ids place_id status trim_user
+    /],
     required   => [qw/status/],
     booleans   => [qw/display_coordinates trim_user/],
     add_source => 1,
@@ -702,8 +705,8 @@ user credentials are valid.
 
     path     => 'account/verify_credentials',
     method   => 'GET',
-    params   => [qw/include_entities skip_status/],
-    booleans => [qw/include_entities skip_status/],
+    params   => [qw/include_entities skip_status include_email/],
+    booleans => [qw/include_entities skip_status include_email/],
     required => [qw//],
     returns  => 'ExtendedUser',
 );
@@ -983,31 +986,44 @@ require authentication.
 
 twitter_api_method user_suggestions_for => (
     aliases     => [qw/follow_suggestions/],
-    path        => 'users/suggestions/:category',
+    path        => 'users/suggestions/:slug',
     method      => 'GET',
-    params      => [qw/category lang/],
-    required    => [qw/category/],
+    params      => [qw/slug lang/],
+    required    => [qw/slug/],
     returns     => 'ArrayRef',
     description => <<''
-Access the users in a given category of the Twitter suggested user list.
+Access the users in a given slug (category) of the Twitter suggested user list.
 
 );
 
 twitter_api_method user_suggestions => (
-    aliases     => [qw/follow_suggestions/],
-    path        => 'users/suggestions/:category/members',
+    aliases     => [qw/follow_suggestions_for/],
+    path        => 'users/suggestions/:slug/members',
     method      => 'GET',
-    params      => [qw/category lang/],
-    required    => [qw/category/],
+    params      => [qw/slug lang/],
+    required    => [qw/slug/],
     returns     => 'ArrayRef',
     description => <<''
-Access the users in a given category of the Twitter suggested user list and
-return their most recent status if they are not a protected user. Currently
-supported values for optional parameter C<lang> are C<en>, C<fr>, C<de>, C<es>,
-C<it>.  Does not require authentication.
+Access the users in a given slug (category) of the Twitter suggested user list
+and return their most recent status if they are not a protected user.
+Currently supported values for optional parameter C<lang> are C<en>, C<fr>,
+C<de>, C<es>, C<it>.  Does not require authentication.
 
 );
 
+# backwards compatibility: Twitter renamed "category" to "slug"
+around [ qw/follow_suggestions follow_suggestions_for user_suggestions
+user_suggestions_for/ ] => sub {
+    my ( $next, $self ) = splice @_, 0, 2;
+
+    my $args = ref $_[-1] eq 'HASH' ? pop : {};
+    if ( exists $args->{category} ) {
+        $args->{slug} = delete $args->{category};
+    }
+
+    return $self->$next(@_, $args);
+};
+
 twitter_api_method favorites => (
     description => <<'',
 Returns the 20 most recent favorite statuses for the authenticating
@@ -1392,13 +1408,27 @@ twitter_api_method geo_id => (
     description => <<'',
 Returns details of a place returned from the C<reverse_geocode> method.
 
-    path => 'geo/id/:id',
-    method => 'GET',
-    params => [qw/id/],
-    required => [qw/id/],
+    path     => 'geo/id/:place_id',
+    method   => 'GET',
+    params   => [qw/place_id/],
+    required => [qw/place_id/],
     returns  => 'HashRef',
 );
 
+# backwards compat for 'geo/id/:id'
+# recast to 'geo/id/:place_id
+around geo_id => sub {
+    my ( $next, $self ) = splice @_, 0, 2;
+
+    my $args = ref $_[-1] eq 'HASH' ? pop @_ : {};
+
+    if ( exists $args->{id} ) {
+        $args->{place_id} = delete $args->{id};
+    }
+
+    return $self->$next(@_, $args);
+};
+
 twitter_api_method reverse_geocode => (
     description => <<EOT,
 Search for places (cities and neighborhoods) that can be attached to a
@@ -2153,7 +2183,7 @@ Net::Twitter::Role::API::RESTv1_1 - A definition of the Twitter REST API v1.1 as
 
 =head1 VERSION
 
-version 4.01020
+version 4.01040
 
 =head1 SYNOPSIS
 
