@@ -1,5 +1,5 @@
 package Net::Twitter::Role::API::UploadMedia;
-$Net::Twitter::Role::API::UploadMedia::VERSION = '4.01020';
+$Net::Twitter::Role::API::UploadMedia::VERSION = '4.01040';
 use Moose::Role;
 use Net::Twitter::API;
 use DateTime::Format::Strptime;
@@ -26,6 +26,16 @@ twitter_api_method upload => (
     description => 'Upload images to twitter without posting them on the timeline'
 );
 
+twitter_api_method upload_status => (
+    path        => 'media/upload',
+    method      => 'GET',
+    params      => [qw/media_id command/],
+    required    => [qw/media_id command/],
+    booleans    => [qw//],
+    returns     => 'status',
+    description => 'Check the status for async video uploads.'
+);
+
 1;
 
 __END__
@@ -36,7 +46,7 @@ Net::Twitter::Role::API::UploadImage - A definition of the Twitter Upload API as
 
 =head1 VERSION
 
-version 4.01020
+version 4.01040
 
 =head1 SYNOPSIS
 
